Fact

Struct Fact 

pub struct Fact { /* private fields */ }
Source-backed service-demand fact for labor planning and exception reporting.

Implementations

Source

impl Fact

pub fn try_new( id: Id, operating_day: Key, demand_units: DemandUnits, source_record_refs: Vec<RecordRef>, projection_version: ProjectionVersion, data_quality_issues: Vec<Issue>, ) -> Result<Self>

Validates and creates the analytics value.

pub const fn id(&self) -> &Id

Returns this analytics value’s id.

pub const fn operating_day(&self) -> &Key

Returns this analytics value’s operating day.

pub const fn demand_units(&self) -> DemandUnits

Returns this analytics value’s demand units.

pub fn source_record_refs(&self) -> &[RecordRef]

Returns the source record refs for this analytics value.

pub const fn projection_version(&self) -> &ProjectionVersion

Returns this analytics value’s projection version.

pub const fn data_quality_status(&self) -> DataQualityStatus

Returns this analytics value’s data quality status.

pub fn data_quality_issues(&self) -> &[Issue]

Returns the data quality issues for this analytics value.